@@ -17,18 +17,23 @@ sub _render_json {
     my $res = $c->create_response(200);
 
     my $encoding = $c->encoding();
-    $encoding = $encoding->mime_name if ref $encoding;
+    $encoding = lc($encoding->mime_name) if ref $encoding;
     if ( ( $c->req->user_agent || '' ) =~ /Opera/ ) {
         $res->content_type(
             "application/x-javascript; charset=$encoding");
     }
+    # chrome bug
+    elsif ( ( $c->req->user_agent || '' ) =~ /Chrome/ and
+        ( $c->req->env->{'HTTP_X_REQUESTED_WITH'} || '' ) ne 'XMLHttpRequest' ) {
+        $res->content_type("text/html; charset=$encoding");
+    }
     else {
         $res->content_type("application/json; charset=$encoding");
     }
 
     # add UTF-8 BOM if the client is Safari
     if ( ( $c->req->user_agent || '' ) =~ m/Safari/ and $encoding eq 'utf-8' ) {
-        $output = "\xEF\xBB\xBF";
+        $output = "\xEF\xBB\xBF" . $output;
     }
 
     $res->content_length(length($output));
